import traceback,re
import json,os
import sys
import tarfile
import subprocess
import logging
from pydantic import BaseModel
from typing import Union
import uvicorn
import datetime
#from fastapi.middleware.cors import CORSMiddleware
from fastapi import APIRouter, HTTPException
from utils.restApi import RESTClient
from utils.utils import sysapp
import shutil
import threading
router = APIRouter()

class Item(BaseModel):
    json_str: str

with open('/home/epm/git/auto_deploy/gtxTs/config.json', 'r') as file:
    configure = json.load(file)
    sysapp.info(configure)
    nfsPath = configure['nfs_path']
    nasPath = configure['nas_path']
    hanaMigPath = configure['hana_mig_path']
    mongoMigPath = configure['mongo_mig_path']
    port = configure['py_port']

def getDbFilelist1(method: str,filePath: str,dbName: str):
    jsonList = []

    onlyFile = True
    if method == 'nfsPri':
        tgtPath='%s%s'%(nfsPath,mongoMigPath)
    elif method == 'nfsPub':
        tgtPath='%s/mongoBackup/all/%s'%(nfsPath,dbName)
        onlyFile=False
    else:
        return {"error": "Invalid method"}
    sysapp.info(tgtPath)
    jsonList = list_files_info(tgtPath,onlyFile)
    return jsonList


def list_files_info(directory,onlyFile):
    fileList = []
    for filename in os.listdir(directory):
        file_path = os.path.join(directory, filename)
        if onlyFile:
            if os.path.isfile(file_path) and 'tar' in filename:
                file_stat = os.stat(file_path)
                file_size = file_stat.st_size
                file_timestamp = file_stat.st_mtime
                normal_time = datetime.datetime.fromtimestamp(file_timestamp)
                file_size = file_size/1024/1024 #convert to MB
                sysapp.debug(f'文件名: {filename}, 时间戳: {normal_time}, 大小: {file_size} MB')
                fileList.append({'name':filename, 'time':normal_time, 'size':file_size})
        else:
            if os.path.isdir(file_path):
                fileTime=os.path.getctime(file_path)
                fileList.append({'name':filename,'time':fileTime})

    file_times_sorted = sorted(fileList, key=lambda x: x['time'],reverse=True)
    return file_times_sorted

def getSchemaFilelist1(tgtSchema: str,method: str,schemaPath: str,schemaName: str):
    jsonList = []

    onlyFile = True
    if method == 'nfsPri':
        tgtPath='%s%s/%s'%(nfsPath,hanaMigPath,tgtSchema)
    elif method == 'nasPri':
        tgtPath='%s%s/%s'%(nasPath,hanaMigPath,tgtSchema)
    elif method == 'nfsPub':
        tgtPath='%s/%s/SCHEMA_BACKUP/%s'%(nfsPath,schemaPath,schemaName)
        onlyFile=False
    else:
        return {"error": "Invalid method"}
    sysapp.info(tgtPath)
    jsonList = list_files_info(tgtPath,onlyFile)
    return jsonList

@router.get(
    "/epm/db/getSchemaFilelist/{tgtSchema}/{method}/{schemaPath}/{schemaName}"
)
def getSchemaFilelist(tgtSchema: str,method: str,schemaPath: str,schemaName: str):
    sysapp.info('%s %s %s',method,schemaPath,schemaName)
    sysapp.info(f'{method} {schemaPath} {schemaName}')
    try:
        jsonList = getSchemaFilelist1(tgtSchema,method,schemaPath,schemaName)
        return jsonList
    except Exception as e:
        sysapp.error(e)
        return {"error": str(e)}

@router.get("/epm/db/getDbFilelist/{method}/{filePath}/{dbName}")
def getDbFilelist(method: str,filePath: str,dbName: str):
    sysapp.info('%s %s %s',method,filePath,dbName)
    try:
        jsonList = getDbFilelist1(method,filePath,dbName)
        return jsonList
    except Exception as e:
        sysapp.error(e)
        return {"error": str(e)}